@@ -10,10 +10,11 @@ use cid::multihash::Code;
 use cid::Cid;
 use fil_actors_runtime::runtime::Policy;
 use fil_actors_runtime::{actor_error, ActorDowncast, ActorError, Array};
-use fvm_shared::blockstore::{Blockstore, CborStore};
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
+use fvm_ipld_encoding::CborStore;
 use fvm_shared::clock::{ChainEpoch, QuantSpec};
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::tuple::*;
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{PoStProof, SectorSize};
 use num_traits::{Signed, Zero};
@@ -361,9 +362,9 @@ impl Deadline {
         self.partitions = partitions.flush()?;
 
         // Update early expiration bitmap.
-        for partition_idx in partitions_with_early_terminations {
-            self.early_terminations.set(partition_idx);
-        }
+        let new_early_terminations = BitField::try_from_bits(partitions_with_early_terminations)
+            .map_err(|_| actor_error!(ErrIllegalState; "partition index out of bitfield range"))?;
+        self.early_terminations |= &new_early_terminations;
 
         let all_on_time_sectors = BitField::union(&on_time_sectors);
         let all_early_sectors = BitField::union(&early_sectors);
@@ -635,9 +636,7 @@ impl Deadline {
         let partition_count = old_partitions.count();
         let to_remove_set: BTreeSet<_> = to_remove
             .bounded_iter(partition_count)
-            .map_err(
-                |e| actor_error!(ErrIllegalArgument; "failed to expand partitions into map: {}", e),
-            )?
+            .ok_or_else(|| actor_error!(ErrIllegalArgument; "partitions to remove exceeds total"))?
             .collect();
 
         if to_remove_set.is_empty() {}
@@ -841,7 +840,7 @@ impl Deadline {
 
             partition
                 .declare_faults_recovered(sectors, sector_size, sector_numbers)
-                .map_err(|e| e.downcast_wrap("failed to add recoveries"))?;
+                .map_err(|e| actor_error!(ErrIllegalState; "failed to add recoveries: {}", e))?;
 
             partitions.set(partition_idx, partition).map_err(|e| {
                 e.downcast_default(
@@ -1118,10 +1117,10 @@ impl Deadline {
         fault_expiration: ChainEpoch,
         post_partitions: &mut [PoStPartition],
     ) -> anyhow::Result<PoStResult> {
-        let mut partition_indexes = BitField::new();
-        for p in post_partitions.iter() {
-            partition_indexes.set(p.index);
-        }
+        let partition_indexes = BitField::try_from_bits(post_partitions.iter().map(|p| p.index))
+            .map_err(
+                |_| actor_error!(ErrIllegalArgument; "partition index out of bitfield range"),
+            )?;
 
         let num_partitions = partition_indexes.len();
         if num_partitions != post_partitions.len() as u64 {
